pub struct PanelTab { /* private fields */ }Trait Implementations
Sourceimpl Component for PanelTab
impl Component for PanelTab
Sourcetype Message = PanelTabMsg
type Message = PanelTabMsg
Messages are used to make Components dynamic and interactive. Simple
Component’s can declare their Message type to be
(). Complex Component’s
commonly use an enum to declare multiple Message types.Sourcetype Properties = PanelTabProps
type Properties = PanelTabProps
The Component’s properties. Read more
Sourcefn changed(&mut self, ctx: &Context<Self>, old: &Self::Properties) -> bool
fn changed(&mut self, ctx: &Context<Self>, old: &Self::Properties) -> bool
Called when properties passed to the component change Read more
Sourcefn update(&mut self, ctx: &Context<Self>, msg: Self::Message) -> bool
fn update(&mut self, ctx: &Context<Self>, msg: Self::Message) -> bool
Called when a new message is sent to the component via its scope. Read more
Sourcefn view(&self, ctx: &Context<Self>) -> Html
fn view(&self, ctx: &Context<Self>) -> Html
Components define their visual layout using a JSX-style syntax through the use of the
html! procedural macro. The full guide to using the macro can be found in Yew’s
documentation. Read moreAuto Trait Implementations
impl !RefUnwindSafe for PanelTab
impl !Send for PanelTab
impl !Sync for PanelTab
impl !UnwindSafe for PanelTab
impl Freeze for PanelTab
impl Unpin for PanelTab
impl UnsafeUnpin for PanelTab