pub struct DragDropEngine(/* private fields */);Expand description
The <perspective-viewer> drag/drop service, which manages drag/drop user
interactions across components. It is a component-level service, since only
one drag/drop action can be executed by the user at a time.
Implementations
Sourceimpl DragDrop
impl DragDrop
Sourcepub fn to_props(&self) -> DragDropProps
pub fn to_props(&self) -> DragDropProps
Snapshot the drag state as a [DragDropProps] value for threading
through the component tree without PubSub subscriptions.
Sourcepub fn get_drag_column(&self) -> Option<String>
pub fn get_drag_column(&self) -> Option<String>
Get the column name currently being drag/dropped.
pub fn get_drag_target(&self) -> Option<DragTarget>
pub fn set_drag_image(&self, event: &DragEvent) -> ApiResult<()>
pub fn is_dragover(&self, drag_target: DragTarget) -> Option<(usize, String)>
pub fn notify_drop(&self, event: &DragEvent)
Sourcepub fn notify_drag_start(&self, column: String, effect: DragEffect)
pub fn notify_drag_start(&self, column: String, effect: DragEffect)
Start the drag/drop action with the name of the column being dragged.
Sourcepub fn notify_drag_end(&self)
pub fn notify_drag_end(&self)
End the drag/drop action by resetting the state to default.
Sourcepub fn notify_drag_leave(&self, drag_target: DragTarget)
pub fn notify_drag_leave(&self, drag_target: DragTarget)
Leave the action zone.
pub fn notify_drag_enter(&self, target: DragTarget, index: usize) -> bool