PresentationEngine

Struct PresentationEngine 

pub struct PresentationEngine(/* private fields */);
State object responsible for the non-persistable/gui element state, including Themes, panel open state and realtive size, title, etc.

Implementations

Source

impl Presentation

pub fn new(elem: &HtmlElement) -> Self

pub fn is_visible(&self) -> bool

pub fn is_active(&self, elem: &Option<Element>) -> bool

pub fn reset_attached(&self)

pub fn get_is_workspace(&self) -> bool

pub fn set_settings_attribute(&self, opt: bool)

pub fn is_settings_open(&self) -> bool

pub fn set_settings_before_open(&self, open: bool)

pub fn set_settings_open(&self, open: bool)

pub fn set_open_column_settings(&self, settings: Option<OpenColumnSettings>)

Sets the currently opened column settings. Emits an internal event on change. Passing None is a shorthand for setting all fields to None.

pub fn get_open_column_settings(&self) -> OpenColumnSettings

Gets a clone of the current OpenColumnSettings.

pub async fn get_available_themes(&self) -> ApiResult<PtrEqRc<Vec<String>>>

Get the available theme names from the browser environment by parsing readable stylesheets. This method is memoized - the state can be flushed by calling reset().

pub async fn reset_available_themes(&self, themes: Option<Vec<String>>) -> bool

Reset the state. styleSheets will be re-parsed next time get_themes() is called if the themes argument is None.

Returns

A bool indicating whether the internal state changed.

pub async fn get_selected_theme_config( &self, ) -> ApiResult<(PtrEqRc<Vec<String>>, Option<usize>)>

pub async fn get_selected_theme_name(&self) -> Option<String>

Returns the currently applied theme, or the default theme if no theme has been set and themes are detected in the document, or None if no themes are available.

pub async fn reset_theme(&self) -> ApiResult<()>

pub async fn set_theme_name(&self, theme: Option<&str>) -> ApiResult<bool>

Set the theme by name, or None for the default theme.

Returns

A bool indicating whether the internal state changed.

pub fn all_columns_configs(&self) -> HashMap<String, ColumnConfigValues>

Returns an owned copy of the curent column configuration map.

pub fn reset_columns_configs(&self)

pub fn get_columns_config( &self, column_name: &str, ) -> Option<ColumnConfigValues>

Gets a clone of the ColumnConfig for the given column name.

pub fn update_columns_configs(&self, update: ColumnConfigUpdate)

Updates the entire column config struct. (like from a restore() call)

pub fn update_columns_config_value( &self, column_name: String, update: ColumnConfigValueUpdate, )

pub fn to_props( &self, available_themes: PtrEqRc<Vec<String>>, ) -> PresentationProps

Snapshot the current presentation state as a [PresentationProps] value suitable for passing as a Yew prop. Called by the root component whenever a presentation-related PubSub event fires.

available_themes must be provided by the caller because theme detection is async and therefore not available synchronously here.