RendererEngine

Struct RendererEngine 

pub struct RendererEngine(/* private fields */);
The state object responsible for the active [JsPerspectiveViewerPlugin].

Implementations

Source

impl Renderer

pub fn new(viewer_elem: &HtmlElement) -> Self

pub async fn reset( &self, columns_config: Option<&HashMap<String, ColumnConfigValues>>, ) -> ApiResult<()>

pub fn delete(&self) -> ApiResult<()>

pub fn metadata(&self) -> Ref<'_, ViewConfigRequirements>

pub fn is_chart(&self) -> bool

pub fn get_all_plugins(&self) -> Vec<JsPerspectiveViewerPlugin>

Return all plugin instances, whether they are active or not. Useful for configuring all or specific plugins at application init.

pub fn get_all_plugin_categories(&self) -> HashMap<String, Vec<String>>

Return all plugin names, whether they are active or not.

pub fn get_active_plugin(&self) -> ApiResult<JsPerspectiveViewerPlugin>

Gets the currently active plugin. Calling this method before a plugin has been selected will cause the default (first) plugin to be selected, and doing so when no plugins have been registered is an error.

pub fn get_plugin(&self, name: &str) -> ApiResult<JsPerspectiveViewerPlugin>

Gets a specific JsPerspectiveViewerPlugin by name.

Arguments
  • name The plugin name to lookup.
pub fn is_plugin_activated(&self) -> ApiResult<bool>

pub async fn restyle_all(&self, view: &View) -> ApiResult<JsValue>

pub fn set_throttle(&self, val: Option<f64>)

pub fn set_selection(&self, window: Option<ViewWindow>)

pub fn get_selection(&self) -> Option<ViewWindow>

pub fn disable_active_plugin_render_warning(&self)

pub fn get_next_plugin_metadata( &self, update: &PluginUpdate, ) -> Option<ViewConfigRequirements>

pub fn apply_pending_plugin(&self) -> ApiResult<bool>

pub async fn with_lock<T>( self, task: impl Future<Output = ApiResult<T>>, ) -> ApiResult<T>

pub async fn resize(&self) -> ApiResult<()>

pub async fn resize_with_dimensions( &self, width: f64, height: f64, ) -> ApiResult<()>

pub async fn draw( &self, session: impl Future<Output = ApiResult<Option<View>>>, ) -> ApiResult<()>

This will take a future which should create a new view and then will draw it. As the session closure is asynchronous, it can be cancelled by returning None.

pub async fn update(&self, session: Option<View>) -> ApiResult<()>

This will update an already existing view

pub async fn presize( &self, open: bool, panel_task: impl Future<Output = ApiResult<()>>, ) -> ApiResult<JsValue>

Decide whether to draw plugin or self first based on whether the panel is opening or closing, then draw with a timeout. If the timeout triggers, draw self and resolve on_toggle but still await the completion of the draw task.

pub fn render_timer(&self) -> MovingWindowRenderTimer

Source

impl Renderer

pub fn to_props(&self, render_limits: Option<RenderLimits>) -> RendererProps

Snapshot the current renderer state as a [RendererProps] value suitable for passing as a Yew prop. Called by the root component whenever a renderer-related PubSub event fires.