SessionEngine

Struct SessionEngine 

pub struct SessionEngine(/* private fields */);
The Session struct is the principal interface to the Perspective engine, the Table and View objects for this viewer, and all associated state including the ViewConfig.

Implementations

Source

impl Session

pub fn new() -> Self

Uses Self::new instead of Default to prevent accidental instantiation in props/etc.

pub fn set_title(&self, title: Option<String>)

pub fn reset( &self, options: ResetOptions, ) -> impl Future<Output = ApiResult<()>> + use<>

Reset this (presumably shared) Session to its initial state, returning a bool indicating whether this Session had a table which was deleted. TODO Table should be an immutable constructor parameter to Session.

pub fn get_table(&self) -> Option<Table>

pub fn set_client(&self, client: Client) -> bool

pub fn get_client(&self) -> Option<Client>

pub async fn set_table(&self, table_name: String) -> ApiResult<bool>

Reset this Session’s state with a new Table. Implicitly clears the ViewSubscription, which will need to be re-initialized later via create_view().

Arguments
  • table_name The name of the Table to load, which must exist on the loaded Client.
Returns

table_name is unique per Client, so if this value has not changed, Session::set_table does nothing and returns Ok(false).

pub fn update_column_defaults(&self, requirements: &ViewConfigRequirements)

pub async fn set_error(&self, reset_table: bool, err: ApiError) -> ApiResult<()>

pub fn set_pause(&self, pause: bool) -> bool

pub async fn await_table(&self) -> ApiResult<()>

pub fn js_get_table(&self) -> Option<JsValue>

pub async fn reconnect(&self) -> ApiResult<()>

pub async fn validate_expr( &self, expr: &str, ) -> Result<Option<ExprValidationError>, ApiError>

Validate an expression string and marshall the results.

pub async fn arrow_as_vec( &self, flat: bool, window: Option<ViewWindow>, ) -> Result<Vec<u8>, ApiError>

pub async fn arrow_as_jsvalue( &self, flat: bool, window: Option<ViewWindow>, ) -> Result<ArrayBuffer, ApiError>

pub async fn ndjson_as_jsvalue( &self, flat: bool, window: Option<ViewWindow>, ) -> Result<JsString, ApiError>

pub async fn json_as_jsvalue( &self, flat: bool, window: Option<ViewWindow>, ) -> Result<Object, ApiError>

pub async fn csv_as_jsvalue( &self, flat: bool, window: Option<ViewWindow>, ) -> Result<JsString, ApiError>

pub fn get_view(&self) -> Option<View>

pub fn get_view_config(&self) -> Ref<'_, ViewConfig>

pub async fn get_column_values( &self, column: String, ) -> Result<Vec<String>, ApiError>

Get all unique column values for a given column name.

Use the .to_csv() method, as I suspected copying this large string once was more efficient than copying many smaller strings, and string copying shows up frequently when doing performance analysis.

TODO Does not work with expressions yet.

Arguments
  • column The name of the column (or expression).
pub fn set_update_column_defaults( &self, config_update: &mut ViewConfigUpdate, requirements: &ViewConfigRequirements, )

pub fn update_view_config( &self, config_update: ViewConfigUpdate, ) -> ApiResult<()>

Update the config, setting the columns property to the plugin defaults if provided.

pub async fn validate(&self) -> Result<ValidSession<'_>, ApiError>

In order to create a new view in this session, the session must first be validated to create a ValidSession<'_> guard.

pub fn to_props(&self) -> SessionProps

Snapshot the current session state as a [SessionProps] value suitable for passing as a Yew prop. Called by the root component whenever a session-related PubSub event fires.