pub trait ModalLink<T>where
T: Component,{
// Required method
fn weak_link(&self) -> &WeakScope<T>;
}Expand description
Props that expose a weak link to their component, so an owner can send it messages after the fact (the column-style editors hosted in a modal).
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".