resolve_css_refs

Function resolve_css_refs 

pub fn resolve_css_refs(
    entry: &mut Map<String, Value>,
    lookup: &dyn Fn(&str) -> Option<String>,
) -> Vec<(String, String)>
Replace every whole-value var(--psp-user--…) string in one column’s config entry with the literal lookup resolves it to, removing and reporting keys that do not resolve.