pub struct PubSub<T: Clone>(/* private fields */);Expand description
A pub/sub struct which allows many listeners to subscribe to many publishers, without leaking callbacks as listeners are dropped.
Unlike mpsc etc., PubSub has no internal queue and is completely
synchronous. Explicitly does not implement clone, as this is intended as
RAII, even though the internal data structures are Clone because they
need to be sent to listeners.
Implementations
Sourceimpl<T: Clone + 'static> PubSub<T>
impl<T: Clone + 'static> PubSub<T>
Sourcepub fn callback(&self) -> Callback<T>
pub fn callback(&self) -> Callback<T>
Get this PubSub<_>’s .emit_all() method as a Callback<T>.
Sourcepub fn add_notify_listener(&self, cb: &Callback<()>) -> Subscription
pub fn add_notify_listener(&self, cb: &Callback<()>) -> Subscription
Subscribe a Callback<()> that fires whenever this PubSub emits,
discarding the emitted value. Useful when the subscriber only
needs a “something changed” notification.
Sourcepub fn as_boxfn(&self) -> Box<dyn Fn(T) + 'static>
pub fn as_boxfn(&self) -> Box<dyn Fn(T) + 'static>
Convert PubSub::emit to a Box<dyn Fn(T)>.
Sourcepub async fn read_next(&self) -> Result<T, Canceled>
pub async fn read_next(&self) -> Result<T, Canceled>
Await this PubSub<_>’s next call to emit_all(), once.
Sourcepub fn subscriber(&self) -> Subscriber<T>
pub fn subscriber(&self) -> Subscriber<T>
Create a Subscriber from this PubSub, which is the reciprocal of
PubSub::callback (a struct which only allows sending), a struct which
only allows receiving via Subscriber::add_listener.