components contains all Yew Component types, but only exports the 4
necessary for public Custom Elements. The rest are internal components of
these 4.
Modules
- column_
dropdown - column_
selector - column_
settings_ sidebar - containers
containersare generic container-like components for collections of otherComponenttypes.- copy_
dropdown - datetime_
column_ style - editable_
header - empty_
row - export_
dropdown - expression_
editor - filter_
dropdown - font_
loader - form
- A module for form controls (though form controls like
<Select>which are also container elements should go in thecontainersmodule). - function_
dropdown - main_
panel - modal
- number_
series_ style - plugin_
selector - plugin_
tab - Plugin-scoped settings tab. Mirrors
style_tabbut operates on the active plugin’ssave()/restore()token rather than a per-column config map. The schema comes fromplugin.plugin_config_schema(); field updates are dispatched throughtasks::send_plugin_config. - portal
- render_
warning - settings_
panel - status_
bar - status_
bar_ counter - status_
indicator - string_
column_ style - style
- A micro-framework for associating local CSS snippets with
yew::Components in a Custom Element’sShadowRoot. - style_
controls - type_
icon - viewer